# Stubs for zope.interface.exceptions (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class Invalid(Exception): ...

class DoesNotImplement(Invalid):
    interface: Any = ...
    def __init__(self, interface: Any) -> None: ...

class BrokenImplementation(Invalid):
    interface: Any = ...
    name: Any = ...
    def __init__(self, interface: Any, name: Any) -> None: ...

class BrokenMethodImplementation(Invalid):
    method: Any = ...
    mess: Any = ...
    def __init__(self, method: Any, mess: Any) -> None: ...

class InvalidInterface(Exception): ...
class BadImplements(TypeError): ...
