# Stubs for zope.interface.document (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

def asStructuredText(I: Any, munge: int = ..., rst: bool = ...): ...
def asReStructuredText(I: Any, munge: int = ...): ...
