# Stubs for zope.interface.verify (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

MethodTypes: Any

def verifyClass(iface: Any, candidate: Any, tentative: int = ...): ...
def verifyObject(iface: Any, candidate: Any, tentative: int = ...): ...
