# Stubs for zope.interface._compat (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

CLASS_TYPES: Any
STRING_TYPES: Any
PYTHON3: bool
PYTHON2: bool
