# Stubs for zope.interface (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from zope.interface.declarations import Declaration as Declaration, alsoProvides as alsoProvides, classImplements as classImplements, classImplementsOnly as classImplementsOnly, classProvides as classProvides, directlyProvidedBy as directlyProvidedBy, directlyProvides as directlyProvides, implementedBy as implementedBy, implementer as implementer, implementer_only as implementer_only, implements as implements, implementsOnly as implementsOnly, moduleProvides as moduleProvides, noLongerProvides as noLongerProvides, providedBy as providedBy, provider as provider, named as named
from zope.interface.interface import Attribute as Attribute, Interface as Interface
from zope.exceptions import Invalid as Invalid, DoesNotImplement as DoesNotImplement, BrokenImplementation as BrokenImplementation, InvalidInterface as InvalidInterface, BadImplements as BadImplements
from zope.interface import adapter as adapter
from zope.interface import advice as advice
from zope.interface import interfaces as interfaces
from zope.interface import declarations as declarations
from zope.interface import document as document
from zope.interface import exceptions as exceptions
from zope.interface import verify as verify
from zope.interface import ro as ro
